@@ -35,6 +35,7 @@ void defaults()
 	state.update_interval = CHK_INTERVAL;
 	state.standard_free = 0;
 	state.mb = 0;
+	state.show_used = 0;
 	safecopy(state.proc_mem_filename, PROC_MEM, 256);
 	withdrawn = 0;
 	iconic = 0; 
@@ -57,12 +58,13 @@ void usage()
         printf("-h -H -help     print this message\n");
         printf("-u <secs>       the update interval in seconds\n");
         printf("-mb             the display is in MBytes\n");
+        printf("-used           display used memory instead of free\n");
         printf("-display <name> the name of the display to use\n");
         printf("-position <xy>  position on the screen (geometry)\n");
         printf("-withdrawn      start in withdrawn shape (for WindowMaker)\n");
         printf("-iconic         start iconized\n");
         printf("-standout       standing out rather than being pushed in\n");
-        printf("-free           use free memory amount as read from device\n");
+        printf("-asis           use free memory amount as read from device\n");
 	printf("-dev <device>	use the specified file as stat device\n\n");
 	printf("-bg <color>	background color\n");
 	printf("-fg <color>	base foreground color\n");
@@ -77,7 +79,7 @@ void usage()
 /* print the version of the tool */
 void version()
 {
-        printf("asmem : AfterStep memory utilization monitor version 1.2\n");
+        printf("asmem : AfterStep memory utilization monitor version 1.3\n");
 }               
 
 void    parsecmdline(int argc, char *argv[])
@@ -95,10 +97,14 @@ void    parsecmdline(int argc, char *argv[])
                                 iconic=1;
                         } else if (!strncmp(argument,"-standout",9)) {
                                 pushed_in=0;
+                        } else if (!strncmp(argument,"-asis",5)) {
+                                state.standard_free=1;
                         } else if (!strncmp(argument,"-free",5)) {
                                 state.standard_free=1;
                         } else if (!strncmp(argument,"-mb",3)) {
                                 state.mb=1;
+                        } else if (!strncmp(argument,"-used",5)) {
+                                state.show_used=1;
                         } else if (!strncmp(argument,"-u",2)) {
                                 if (++i >= argc)
                                         usage();
