@@ -118,6 +118,8 @@ void draw_window(Window win)
 		free_mem = state.fresh.free
 			+state.fresh.buffers
 			+state.fresh.cached;
+	if ( state.show_used )
+		free_mem = state.fresh.total - free_mem;
 	if ( (state.fresh.total > (999999 * 1024))
 			|| state.mb )
 		available = free_mem / 1024 / 1024;
@@ -269,11 +271,14 @@ void draw_window(Window win)
 				);
 	}
 
-	if ( (state.fresh.swap_total > (999999*1024))
+	free_mem = state.fresh.swap_free;
+	if ( state.show_used )
+		free_mem = state.fresh.swap_total - free_mem;
+	if ( (free_mem > (999999*1024))
 			|| state.mb )
-		available = state.fresh.swap_free / 1024 / 1024;
+		available = free_mem / 1024 / 1024;
 	else
-		available = state.fresh.swap_free / 1024;
+		available = free_mem / 1024;
 	digits = 0;
 	for (i=0 ; i<6; ++i) {
 		tmp[i] = available % 10;
@@ -298,7 +303,7 @@ void draw_window(Window win)
 	}
 
 	percentage = (int) (
-			((float)state.fresh.swap_free) /
+			((float)free_mem) /
 			((float)state.fresh.swap_total) * 100);
 	if (percentage >= 100) 
 		tmp[0] = percentage / 100;
@@ -519,7 +524,7 @@ void asmem_initialize(
                 &backgroundXpm.attributes
                 );
         if(status != XpmSuccess) {
-                printf("ascpu : (%d) not enough free color cells for background.\n", status);   
+                printf("asmem : (%d) not enough free color cells for background.\n", status);   
 		asmem_cleanup();
         }       
 #ifdef DEBUG
